@@ -2095,5 +2095,8 @@ binlessfit <- function(o, conf.level = .95, llam.quant = NULL, span = NULL, ...)
   
 }
 
-
-
+.onAttach <- function(libname, pkgname) {
+  packageStartupMessage(paste0("tidyvpc is part of Certara.R!\n",
+                               "Follow the link below to learn more about R package development at Cerara.\n",
+                               "https://certara.github.io/R-Certara/"))
+}
